struct Validator<T: NodeType> {
membership_coordinator: EpochMembershipCoordinator<T>,
epoch_height: u64,
upgrade_lock: UpgradeLock<T>,
}Fields
membership_coordinator: EpochMembershipCoordinator<T>epoch_height: u64upgrade_lock: UpgradeLock<T>Implementations
Sourceimpl<T: NodeType> Validator<T>
impl<T: NodeType> Validator<T>
Sourceasync fn signature(
&self,
proposal: &SignedProposal<T, Proposal<T>>,
) -> Result<T::SignatureKey, ValidationError>
async fn signature( &self, proposal: &SignedProposal<T, Proposal<T>>, ) -> Result<T::SignatureKey, ValidationError>
Verify the proposal signature and return the leader
Sourceasync fn justify_qc(
&self,
proposal: &Proposal<T>,
) -> Result<(), ValidationError>
async fn justify_qc( &self, proposal: &Proposal<T>, ) -> Result<(), ValidationError>
Verify the QC of the proposal
Sourceasync fn next_epoch_justify_qc(
&self,
proposal: &Proposal<T>,
) -> Result<(), ValidationError>
async fn next_epoch_justify_qc( &self, proposal: &Proposal<T>, ) -> Result<(), ValidationError>
Verify the next-epoch justify QC on the first proposal of an epoch.
If the previous block is the last block of an epoch, this proposal is
the first of the new epoch and must carry a next_epoch_justify_qc
over the same leaf as its justify QC.
Sourceasync fn view_change_evidence(
&self,
proposal: &Proposal<T>,
) -> Result<(), ValidationError>
async fn view_change_evidence( &self, proposal: &Proposal<T>, ) -> Result<(), ValidationError>
Validate the proposal’s view-change evidence (timeout certificate).
Sourceasync fn state_cert(
&self,
proposal: &Proposal<T>,
) -> Result<(), ValidationError>
async fn state_cert( &self, proposal: &Proposal<T>, ) -> Result<(), ValidationError>
Validate the state_cert on an epoch-root proposal.
If the justify_qc points at an epoch-root block, the proposal MUST
carry a matching LightClientStateUpdateCertificateV2.
async fn membership( &self, epoch: EpochNumber, ) -> Result<EpochMembership<T>, ValidationError>